# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGenaiAgentResult',
    'AwaitableGetGenaiAgentResult',
    'get_genai_agent',
    'get_genai_agent_output',
]

@pulumi.output_type
class GetGenaiAgentResult:
    """
    A collection of values returned by getGenaiAgent.
    """
    def __init__(__self__, agent_guardrails=None, agent_id=None, anthropic_api_keys=None, api_key_infos=None, api_keys=None, chatbot_identifiers=None, chatbots=None, child_agents=None, created_at=None, deployments=None, description=None, functions=None, id=None, if_case=None, instruction=None, k=None, knowledge_bases=None, max_tokens=None, model_uuid=None, models=None, name=None, open_ai_api_keys=None, parent_agents=None, project_id=None, region=None, retrieval_method=None, route_created_at=None, route_created_by=None, route_name=None, route_uuid=None, tags=None, temperature=None, templates=None, top_p=None, updated_at=None, url=None, user_id=None):
        if agent_guardrails and not isinstance(agent_guardrails, list):
            raise TypeError("Expected argument 'agent_guardrails' to be a list")
        pulumi.set(__self__, "agent_guardrails", agent_guardrails)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if anthropic_api_keys and not isinstance(anthropic_api_keys, list):
            raise TypeError("Expected argument 'anthropic_api_keys' to be a list")
        pulumi.set(__self__, "anthropic_api_keys", anthropic_api_keys)
        if api_key_infos and not isinstance(api_key_infos, list):
            raise TypeError("Expected argument 'api_key_infos' to be a list")
        pulumi.set(__self__, "api_key_infos", api_key_infos)
        if api_keys and not isinstance(api_keys, list):
            raise TypeError("Expected argument 'api_keys' to be a list")
        pulumi.set(__self__, "api_keys", api_keys)
        if chatbot_identifiers and not isinstance(chatbot_identifiers, list):
            raise TypeError("Expected argument 'chatbot_identifiers' to be a list")
        pulumi.set(__self__, "chatbot_identifiers", chatbot_identifiers)
        if chatbots and not isinstance(chatbots, list):
            raise TypeError("Expected argument 'chatbots' to be a list")
        pulumi.set(__self__, "chatbots", chatbots)
        if child_agents and not isinstance(child_agents, list):
            raise TypeError("Expected argument 'child_agents' to be a list")
        pulumi.set(__self__, "child_agents", child_agents)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if deployments and not isinstance(deployments, list):
            raise TypeError("Expected argument 'deployments' to be a list")
        pulumi.set(__self__, "deployments", deployments)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if functions and not isinstance(functions, list):
            raise TypeError("Expected argument 'functions' to be a list")
        pulumi.set(__self__, "functions", functions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if if_case and not isinstance(if_case, str):
            raise TypeError("Expected argument 'if_case' to be a str")
        pulumi.set(__self__, "if_case", if_case)
        if instruction and not isinstance(instruction, str):
            raise TypeError("Expected argument 'instruction' to be a str")
        pulumi.set(__self__, "instruction", instruction)
        if k and not isinstance(k, int):
            raise TypeError("Expected argument 'k' to be a int")
        pulumi.set(__self__, "k", k)
        if knowledge_bases and not isinstance(knowledge_bases, list):
            raise TypeError("Expected argument 'knowledge_bases' to be a list")
        pulumi.set(__self__, "knowledge_bases", knowledge_bases)
        if max_tokens and not isinstance(max_tokens, int):
            raise TypeError("Expected argument 'max_tokens' to be a int")
        pulumi.set(__self__, "max_tokens", max_tokens)
        if model_uuid and not isinstance(model_uuid, str):
            raise TypeError("Expected argument 'model_uuid' to be a str")
        pulumi.set(__self__, "model_uuid", model_uuid)
        if models and not isinstance(models, list):
            raise TypeError("Expected argument 'models' to be a list")
        pulumi.set(__self__, "models", models)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if open_ai_api_keys and not isinstance(open_ai_api_keys, list):
            raise TypeError("Expected argument 'open_ai_api_keys' to be a list")
        pulumi.set(__self__, "open_ai_api_keys", open_ai_api_keys)
        if parent_agents and not isinstance(parent_agents, list):
            raise TypeError("Expected argument 'parent_agents' to be a list")
        pulumi.set(__self__, "parent_agents", parent_agents)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if retrieval_method and not isinstance(retrieval_method, str):
            raise TypeError("Expected argument 'retrieval_method' to be a str")
        pulumi.set(__self__, "retrieval_method", retrieval_method)
        if route_created_at and not isinstance(route_created_at, str):
            raise TypeError("Expected argument 'route_created_at' to be a str")
        pulumi.set(__self__, "route_created_at", route_created_at)
        if route_created_by and not isinstance(route_created_by, str):
            raise TypeError("Expected argument 'route_created_by' to be a str")
        pulumi.set(__self__, "route_created_by", route_created_by)
        if route_name and not isinstance(route_name, str):
            raise TypeError("Expected argument 'route_name' to be a str")
        pulumi.set(__self__, "route_name", route_name)
        if route_uuid and not isinstance(route_uuid, str):
            raise TypeError("Expected argument 'route_uuid' to be a str")
        pulumi.set(__self__, "route_uuid", route_uuid)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if temperature and not isinstance(temperature, float):
            raise TypeError("Expected argument 'temperature' to be a float")
        pulumi.set(__self__, "temperature", temperature)
        if templates and not isinstance(templates, list):
            raise TypeError("Expected argument 'templates' to be a list")
        pulumi.set(__self__, "templates", templates)
        if top_p and not isinstance(top_p, float):
            raise TypeError("Expected argument 'top_p' to be a float")
        pulumi.set(__self__, "top_p", top_p)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="agentGuardrails")
    def agent_guardrails(self) -> Optional[Sequence['outputs.GetGenaiAgentAgentGuardrailResult']]:
        return pulumi.get(self, "agent_guardrails")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter(name="anthropicApiKeys")
    def anthropic_api_keys(self) -> Optional[Sequence['outputs.GetGenaiAgentAnthropicApiKeyResult']]:
        return pulumi.get(self, "anthropic_api_keys")

    @_builtins.property
    @pulumi.getter(name="apiKeyInfos")
    def api_key_infos(self) -> Optional[Sequence['outputs.GetGenaiAgentApiKeyInfoResult']]:
        return pulumi.get(self, "api_key_infos")

    @_builtins.property
    @pulumi.getter(name="apiKeys")
    def api_keys(self) -> Optional[Sequence['outputs.GetGenaiAgentApiKeyResult']]:
        return pulumi.get(self, "api_keys")

    @_builtins.property
    @pulumi.getter(name="chatbotIdentifiers")
    def chatbot_identifiers(self) -> Optional[Sequence['outputs.GetGenaiAgentChatbotIdentifierResult']]:
        return pulumi.get(self, "chatbot_identifiers")

    @_builtins.property
    @pulumi.getter
    def chatbots(self) -> Optional[Sequence['outputs.GetGenaiAgentChatbotResult']]:
        return pulumi.get(self, "chatbots")

    @_builtins.property
    @pulumi.getter(name="childAgents")
    def child_agents(self) -> Sequence['outputs.GetGenaiAgentChildAgentResult']:
        return pulumi.get(self, "child_agents")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def deployments(self) -> Optional[Sequence['outputs.GetGenaiAgentDeploymentResult']]:
        return pulumi.get(self, "deployments")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def functions(self) -> Optional[Sequence['outputs.GetGenaiAgentFunctionResult']]:
        return pulumi.get(self, "functions")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ifCase")
    def if_case(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "if_case")

    @_builtins.property
    @pulumi.getter
    def instruction(self) -> _builtins.str:
        return pulumi.get(self, "instruction")

    @_builtins.property
    @pulumi.getter
    def k(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "k")

    @_builtins.property
    @pulumi.getter(name="knowledgeBases")
    def knowledge_bases(self) -> Optional[Sequence['outputs.GetGenaiAgentKnowledgeBaseResult']]:
        return pulumi.get(self, "knowledge_bases")

    @_builtins.property
    @pulumi.getter(name="maxTokens")
    def max_tokens(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "max_tokens")

    @_builtins.property
    @pulumi.getter(name="modelUuid")
    def model_uuid(self) -> _builtins.str:
        return pulumi.get(self, "model_uuid")

    @_builtins.property
    @pulumi.getter
    def models(self) -> Sequence['outputs.GetGenaiAgentModelResult']:
        return pulumi.get(self, "models")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="openAiApiKeys")
    def open_ai_api_keys(self) -> Optional[Sequence['outputs.GetGenaiAgentOpenAiApiKeyResult']]:
        return pulumi.get(self, "open_ai_api_keys")

    @_builtins.property
    @pulumi.getter(name="parentAgents")
    def parent_agents(self) -> Sequence['outputs.GetGenaiAgentParentAgentResult']:
        return pulumi.get(self, "parent_agents")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="retrievalMethod")
    def retrieval_method(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "retrieval_method")

    @_builtins.property
    @pulumi.getter(name="routeCreatedAt")
    def route_created_at(self) -> _builtins.str:
        return pulumi.get(self, "route_created_at")

    @_builtins.property
    @pulumi.getter(name="routeCreatedBy")
    def route_created_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "route_created_by")

    @_builtins.property
    @pulumi.getter(name="routeName")
    def route_name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "route_name")

    @_builtins.property
    @pulumi.getter(name="routeUuid")
    def route_uuid(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "route_uuid")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def temperature(self) -> Optional[_builtins.float]:
        return pulumi.get(self, "temperature")

    @_builtins.property
    @pulumi.getter
    def templates(self) -> Optional[Sequence['outputs.GetGenaiAgentTemplateResult']]:
        return pulumi.get(self, "templates")

    @_builtins.property
    @pulumi.getter(name="topP")
    def top_p(self) -> Optional[_builtins.float]:
        return pulumi.get(self, "top_p")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "user_id")


class AwaitableGetGenaiAgentResult(GetGenaiAgentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGenaiAgentResult(
            agent_guardrails=self.agent_guardrails,
            agent_id=self.agent_id,
            anthropic_api_keys=self.anthropic_api_keys,
            api_key_infos=self.api_key_infos,
            api_keys=self.api_keys,
            chatbot_identifiers=self.chatbot_identifiers,
            chatbots=self.chatbots,
            child_agents=self.child_agents,
            created_at=self.created_at,
            deployments=self.deployments,
            description=self.description,
            functions=self.functions,
            id=self.id,
            if_case=self.if_case,
            instruction=self.instruction,
            k=self.k,
            knowledge_bases=self.knowledge_bases,
            max_tokens=self.max_tokens,
            model_uuid=self.model_uuid,
            models=self.models,
            name=self.name,
            open_ai_api_keys=self.open_ai_api_keys,
            parent_agents=self.parent_agents,
            project_id=self.project_id,
            region=self.region,
            retrieval_method=self.retrieval_method,
            route_created_at=self.route_created_at,
            route_created_by=self.route_created_by,
            route_name=self.route_name,
            route_uuid=self.route_uuid,
            tags=self.tags,
            temperature=self.temperature,
            templates=self.templates,
            top_p=self.top_p,
            updated_at=self.updated_at,
            url=self.url,
            user_id=self.user_id)


def get_genai_agent(agent_guardrails: Optional[Sequence[Union['GetGenaiAgentAgentGuardrailArgs', 'GetGenaiAgentAgentGuardrailArgsDict']]] = None,
                    agent_id: Optional[_builtins.str] = None,
                    anthropic_api_keys: Optional[Sequence[Union['GetGenaiAgentAnthropicApiKeyArgs', 'GetGenaiAgentAnthropicApiKeyArgsDict']]] = None,
                    api_key_infos: Optional[Sequence[Union['GetGenaiAgentApiKeyInfoArgs', 'GetGenaiAgentApiKeyInfoArgsDict']]] = None,
                    api_keys: Optional[Sequence[Union['GetGenaiAgentApiKeyArgs', 'GetGenaiAgentApiKeyArgsDict']]] = None,
                    chatbot_identifiers: Optional[Sequence[Union['GetGenaiAgentChatbotIdentifierArgs', 'GetGenaiAgentChatbotIdentifierArgsDict']]] = None,
                    chatbots: Optional[Sequence[Union['GetGenaiAgentChatbotArgs', 'GetGenaiAgentChatbotArgsDict']]] = None,
                    deployments: Optional[Sequence[Union['GetGenaiAgentDeploymentArgs', 'GetGenaiAgentDeploymentArgsDict']]] = None,
                    description: Optional[_builtins.str] = None,
                    functions: Optional[Sequence[Union['GetGenaiAgentFunctionArgs', 'GetGenaiAgentFunctionArgsDict']]] = None,
                    if_case: Optional[_builtins.str] = None,
                    k: Optional[_builtins.int] = None,
                    knowledge_bases: Optional[Sequence[Union['GetGenaiAgentKnowledgeBaseArgs', 'GetGenaiAgentKnowledgeBaseArgsDict']]] = None,
                    max_tokens: Optional[_builtins.int] = None,
                    models: Optional[Sequence[Union['GetGenaiAgentModelArgs', 'GetGenaiAgentModelArgsDict']]] = None,
                    open_ai_api_keys: Optional[Sequence[Union['GetGenaiAgentOpenAiApiKeyArgs', 'GetGenaiAgentOpenAiApiKeyArgsDict']]] = None,
                    retrieval_method: Optional[_builtins.str] = None,
                    route_created_by: Optional[_builtins.str] = None,
                    route_name: Optional[_builtins.str] = None,
                    route_uuid: Optional[_builtins.str] = None,
                    tags: Optional[Sequence[_builtins.str]] = None,
                    temperature: Optional[_builtins.float] = None,
                    templates: Optional[Sequence[Union['GetGenaiAgentTemplateArgs', 'GetGenaiAgentTemplateArgsDict']]] = None,
                    top_p: Optional[_builtins.float] = None,
                    url: Optional[_builtins.str] = None,
                    user_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGenaiAgentResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['agentGuardrails'] = agent_guardrails
    __args__['agentId'] = agent_id
    __args__['anthropicApiKeys'] = anthropic_api_keys
    __args__['apiKeyInfos'] = api_key_infos
    __args__['apiKeys'] = api_keys
    __args__['chatbotIdentifiers'] = chatbot_identifiers
    __args__['chatbots'] = chatbots
    __args__['deployments'] = deployments
    __args__['description'] = description
    __args__['functions'] = functions
    __args__['ifCase'] = if_case
    __args__['k'] = k
    __args__['knowledgeBases'] = knowledge_bases
    __args__['maxTokens'] = max_tokens
    __args__['models'] = models
    __args__['openAiApiKeys'] = open_ai_api_keys
    __args__['retrievalMethod'] = retrieval_method
    __args__['routeCreatedBy'] = route_created_by
    __args__['routeName'] = route_name
    __args__['routeUuid'] = route_uuid
    __args__['tags'] = tags
    __args__['temperature'] = temperature
    __args__['templates'] = templates
    __args__['topP'] = top_p
    __args__['url'] = url
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getGenaiAgent:getGenaiAgent', __args__, opts=opts, typ=GetGenaiAgentResult).value

    return AwaitableGetGenaiAgentResult(
        agent_guardrails=pulumi.get(__ret__, 'agent_guardrails'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        anthropic_api_keys=pulumi.get(__ret__, 'anthropic_api_keys'),
        api_key_infos=pulumi.get(__ret__, 'api_key_infos'),
        api_keys=pulumi.get(__ret__, 'api_keys'),
        chatbot_identifiers=pulumi.get(__ret__, 'chatbot_identifiers'),
        chatbots=pulumi.get(__ret__, 'chatbots'),
        child_agents=pulumi.get(__ret__, 'child_agents'),
        created_at=pulumi.get(__ret__, 'created_at'),
        deployments=pulumi.get(__ret__, 'deployments'),
        description=pulumi.get(__ret__, 'description'),
        functions=pulumi.get(__ret__, 'functions'),
        id=pulumi.get(__ret__, 'id'),
        if_case=pulumi.get(__ret__, 'if_case'),
        instruction=pulumi.get(__ret__, 'instruction'),
        k=pulumi.get(__ret__, 'k'),
        knowledge_bases=pulumi.get(__ret__, 'knowledge_bases'),
        max_tokens=pulumi.get(__ret__, 'max_tokens'),
        model_uuid=pulumi.get(__ret__, 'model_uuid'),
        models=pulumi.get(__ret__, 'models'),
        name=pulumi.get(__ret__, 'name'),
        open_ai_api_keys=pulumi.get(__ret__, 'open_ai_api_keys'),
        parent_agents=pulumi.get(__ret__, 'parent_agents'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        retrieval_method=pulumi.get(__ret__, 'retrieval_method'),
        route_created_at=pulumi.get(__ret__, 'route_created_at'),
        route_created_by=pulumi.get(__ret__, 'route_created_by'),
        route_name=pulumi.get(__ret__, 'route_name'),
        route_uuid=pulumi.get(__ret__, 'route_uuid'),
        tags=pulumi.get(__ret__, 'tags'),
        temperature=pulumi.get(__ret__, 'temperature'),
        templates=pulumi.get(__ret__, 'templates'),
        top_p=pulumi.get(__ret__, 'top_p'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        url=pulumi.get(__ret__, 'url'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_genai_agent_output(agent_guardrails: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentAgentGuardrailArgs', 'GetGenaiAgentAgentGuardrailArgsDict']]]]] = None,
                           agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                           anthropic_api_keys: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentAnthropicApiKeyArgs', 'GetGenaiAgentAnthropicApiKeyArgsDict']]]]] = None,
                           api_key_infos: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentApiKeyInfoArgs', 'GetGenaiAgentApiKeyInfoArgsDict']]]]] = None,
                           api_keys: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentApiKeyArgs', 'GetGenaiAgentApiKeyArgsDict']]]]] = None,
                           chatbot_identifiers: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentChatbotIdentifierArgs', 'GetGenaiAgentChatbotIdentifierArgsDict']]]]] = None,
                           chatbots: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentChatbotArgs', 'GetGenaiAgentChatbotArgsDict']]]]] = None,
                           deployments: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentDeploymentArgs', 'GetGenaiAgentDeploymentArgsDict']]]]] = None,
                           description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           functions: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentFunctionArgs', 'GetGenaiAgentFunctionArgsDict']]]]] = None,
                           if_case: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           k: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                           knowledge_bases: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentKnowledgeBaseArgs', 'GetGenaiAgentKnowledgeBaseArgsDict']]]]] = None,
                           max_tokens: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                           models: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentModelArgs', 'GetGenaiAgentModelArgsDict']]]]] = None,
                           open_ai_api_keys: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentOpenAiApiKeyArgs', 'GetGenaiAgentOpenAiApiKeyArgsDict']]]]] = None,
                           retrieval_method: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           route_created_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           route_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           route_uuid: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                           temperature: Optional[pulumi.Input[Optional[_builtins.float]]] = None,
                           templates: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentTemplateArgs', 'GetGenaiAgentTemplateArgsDict']]]]] = None,
                           top_p: Optional[pulumi.Input[Optional[_builtins.float]]] = None,
                           url: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           user_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGenaiAgentResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['agentGuardrails'] = agent_guardrails
    __args__['agentId'] = agent_id
    __args__['anthropicApiKeys'] = anthropic_api_keys
    __args__['apiKeyInfos'] = api_key_infos
    __args__['apiKeys'] = api_keys
    __args__['chatbotIdentifiers'] = chatbot_identifiers
    __args__['chatbots'] = chatbots
    __args__['deployments'] = deployments
    __args__['description'] = description
    __args__['functions'] = functions
    __args__['ifCase'] = if_case
    __args__['k'] = k
    __args__['knowledgeBases'] = knowledge_bases
    __args__['maxTokens'] = max_tokens
    __args__['models'] = models
    __args__['openAiApiKeys'] = open_ai_api_keys
    __args__['retrievalMethod'] = retrieval_method
    __args__['routeCreatedBy'] = route_created_by
    __args__['routeName'] = route_name
    __args__['routeUuid'] = route_uuid
    __args__['tags'] = tags
    __args__['temperature'] = temperature
    __args__['templates'] = templates
    __args__['topP'] = top_p
    __args__['url'] = url
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getGenaiAgent:getGenaiAgent', __args__, opts=opts, typ=GetGenaiAgentResult)
    return __ret__.apply(lambda __response__: GetGenaiAgentResult(
        agent_guardrails=pulumi.get(__response__, 'agent_guardrails'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        anthropic_api_keys=pulumi.get(__response__, 'anthropic_api_keys'),
        api_key_infos=pulumi.get(__response__, 'api_key_infos'),
        api_keys=pulumi.get(__response__, 'api_keys'),
        chatbot_identifiers=pulumi.get(__response__, 'chatbot_identifiers'),
        chatbots=pulumi.get(__response__, 'chatbots'),
        child_agents=pulumi.get(__response__, 'child_agents'),
        created_at=pulumi.get(__response__, 'created_at'),
        deployments=pulumi.get(__response__, 'deployments'),
        description=pulumi.get(__response__, 'description'),
        functions=pulumi.get(__response__, 'functions'),
        id=pulumi.get(__response__, 'id'),
        if_case=pulumi.get(__response__, 'if_case'),
        instruction=pulumi.get(__response__, 'instruction'),
        k=pulumi.get(__response__, 'k'),
        knowledge_bases=pulumi.get(__response__, 'knowledge_bases'),
        max_tokens=pulumi.get(__response__, 'max_tokens'),
        model_uuid=pulumi.get(__response__, 'model_uuid'),
        models=pulumi.get(__response__, 'models'),
        name=pulumi.get(__response__, 'name'),
        open_ai_api_keys=pulumi.get(__response__, 'open_ai_api_keys'),
        parent_agents=pulumi.get(__response__, 'parent_agents'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        retrieval_method=pulumi.get(__response__, 'retrieval_method'),
        route_created_at=pulumi.get(__response__, 'route_created_at'),
        route_created_by=pulumi.get(__response__, 'route_created_by'),
        route_name=pulumi.get(__response__, 'route_name'),
        route_uuid=pulumi.get(__response__, 'route_uuid'),
        tags=pulumi.get(__response__, 'tags'),
        temperature=pulumi.get(__response__, 'temperature'),
        templates=pulumi.get(__response__, 'templates'),
        top_p=pulumi.get(__response__, 'top_p'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        url=pulumi.get(__response__, 'url'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SpacesKeyArgs', 'SpacesKey']

@pulumi.input_type
class SpacesKeyArgs:
    def __init__(__self__, *,
                 grants: Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SpacesKey resource.
        :param pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]] grants: A grant for the key (documented below).
        :param pulumi.Input[_builtins.str] name: The name of the key
        """
        if grants is not None:
            pulumi.set(__self__, "grants", grants)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def grants(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]]:
        """
        A grant for the key (documented below).
        """
        return pulumi.get(self, "grants")

    @grants.setter
    def grants(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]]):
        pulumi.set(self, "grants", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SpacesKeyState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 grants: Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SpacesKey resources.
        :param pulumi.Input[_builtins.str] access_key: The access key ID of the key
        :param pulumi.Input[_builtins.str] created_at: The creation time of the key
        :param pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]] grants: A grant for the key (documented below).
        :param pulumi.Input[_builtins.str] name: The name of the key
        :param pulumi.Input[_builtins.str] secret_key: The access key secret of the key
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if grants is not None:
            pulumi.set(__self__, "grants", grants)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key ID of the key
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The creation time of the key
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def grants(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]]:
        """
        A grant for the key (documented below).
        """
        return pulumi.get(self, "grants")

    @grants.setter
    def grants(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SpacesKeyGrantArgs']]]]):
        pulumi.set(self, "grants", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key secret of the key
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)


@pulumi.type_token("digitalocean:index/spacesKey:SpacesKey")
class SpacesKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grants: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpacesKeyGrantArgs', 'SpacesKeyGrantArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a key resource for Spaces, DigitalOcean's object storage product.

        The [Spaces API](https://docs.digitalocean.com/reference/api/spaces-api/) was
        designed to be interoperable with Amazon's AWS S3 API. This allows users to
        interact with the service while using the tools they already know. Spaces
        mirrors S3's authentication framework and requests to Spaces require a key pair
        similar to Amazon's Access ID and Secret Key.

        As a Spaces owner, you limit others’ access to your buckets using Spaces access
        keys. Access keys can provide several levels of permissions to create, destroy,
        read, and write to specific associated buckets. However, access keys only limit
        access to certain commands using the S3 API or CLI, not the control panel or
        other DigitalOcean resources.

        ## Example Usage

        ### Create a New Key

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar", name="foobar")
        ```

        ### Create a New Key with Grants

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar",
            name="foobar",
            grants=[{
                "bucket": "my-bucket",
                "permission": "read",
            }])
        ```

        ### Create a New Key with full access

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar",
            name="foobar",
            grants=[{
                "bucket": "",
                "permission": "fullaccess",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SpacesKeyGrantArgs', 'SpacesKeyGrantArgsDict']]]] grants: A grant for the key (documented below).
        :param pulumi.Input[_builtins.str] name: The name of the key
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SpacesKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a key resource for Spaces, DigitalOcean's object storage product.

        The [Spaces API](https://docs.digitalocean.com/reference/api/spaces-api/) was
        designed to be interoperable with Amazon's AWS S3 API. This allows users to
        interact with the service while using the tools they already know. Spaces
        mirrors S3's authentication framework and requests to Spaces require a key pair
        similar to Amazon's Access ID and Secret Key.

        As a Spaces owner, you limit others’ access to your buckets using Spaces access
        keys. Access keys can provide several levels of permissions to create, destroy,
        read, and write to specific associated buckets. However, access keys only limit
        access to certain commands using the S3 API or CLI, not the control panel or
        other DigitalOcean resources.

        ## Example Usage

        ### Create a New Key

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar", name="foobar")
        ```

        ### Create a New Key with Grants

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar",
            name="foobar",
            grants=[{
                "bucket": "my-bucket",
                "permission": "read",
            }])
        ```

        ### Create a New Key with full access

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.SpacesKey("foobar",
            name="foobar",
            grants=[{
                "bucket": "",
                "permission": "fullaccess",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param SpacesKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SpacesKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grants: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpacesKeyGrantArgs', 'SpacesKeyGrantArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SpacesKeyArgs.__new__(SpacesKeyArgs)

            __props__.__dict__["grants"] = grants
            __props__.__dict__["name"] = name
            __props__.__dict__["access_key"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["secret_key"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SpacesKey, __self__).__init__(
            'digitalocean:index/spacesKey:SpacesKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            grants: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpacesKeyGrantArgs', 'SpacesKeyGrantArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None) -> 'SpacesKey':
        """
        Get an existing SpacesKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key ID of the key
        :param pulumi.Input[_builtins.str] created_at: The creation time of the key
        :param pulumi.Input[Sequence[pulumi.Input[Union['SpacesKeyGrantArgs', 'SpacesKeyGrantArgsDict']]]] grants: A grant for the key (documented below).
        :param pulumi.Input[_builtins.str] name: The name of the key
        :param pulumi.Input[_builtins.str] secret_key: The access key secret of the key
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SpacesKeyState.__new__(_SpacesKeyState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["grants"] = grants
        __props__.__dict__["name"] = name
        __props__.__dict__["secret_key"] = secret_key
        return SpacesKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[_builtins.str]:
        """
        The access key ID of the key
        """
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The creation time of the key
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def grants(self) -> pulumi.Output[Optional[Sequence['outputs.SpacesKeyGrant']]]:
        """
        A grant for the key (documented below).
        """
        return pulumi.get(self, "grants")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the key
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        The access key secret of the key
        """
        return pulumi.get(self, "secret_key")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 purpose: Optional[pulumi.Input[_builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[_builtins.str] description: the description of the project
        :param pulumi.Input[_builtins.str] environment: the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        :param pulumi.Input[_builtins.bool] is_default: a boolean indicating whether or not the project is the default project. (Default: "false")
        :param pulumi.Input[_builtins.str] name: The name of the Project
        :param pulumi.Input[_builtins.str] purpose: the purpose of the project, (Default: "Web Application")
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] resources: a list of uniform resource names (URNs) for the resources associated with the project
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if purpose is not None:
            pulumi.set(__self__, "purpose", purpose)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the description of the project
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        a boolean indicating whether or not the project is the default project. (Default: "false")
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Project
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def purpose(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the purpose of the project, (Default: "Web Application")
        """
        return pulumi.get(self, "purpose")

    @purpose.setter
    def purpose(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "purpose", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a list of uniform resource names (URNs) for the resources associated with the project
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "resources", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_id: Optional[pulumi.Input[_builtins.int]] = None,
                 owner_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 purpose: Optional[pulumi.Input[_builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[_builtins.str] created_at: the date and time when the project was created, (ISO8601)
        :param pulumi.Input[_builtins.str] description: the description of the project
        :param pulumi.Input[_builtins.str] environment: the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        :param pulumi.Input[_builtins.bool] is_default: a boolean indicating whether or not the project is the default project. (Default: "false")
        :param pulumi.Input[_builtins.str] name: The name of the Project
        :param pulumi.Input[_builtins.int] owner_id: the id of the project owner.
        :param pulumi.Input[_builtins.str] owner_uuid: the unique universal identifier of the project owner.
        :param pulumi.Input[_builtins.str] purpose: the purpose of the project, (Default: "Web Application")
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] resources: a list of uniform resource names (URNs) for the resources associated with the project
        :param pulumi.Input[_builtins.str] updated_at: the date and time when the project was last updated, (ISO8601)
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner_id is not None:
            pulumi.set(__self__, "owner_id", owner_id)
        if owner_uuid is not None:
            pulumi.set(__self__, "owner_uuid", owner_uuid)
        if purpose is not None:
            pulumi.set(__self__, "purpose", purpose)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the date and time when the project was created, (ISO8601)
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the description of the project
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        a boolean indicating whether or not the project is the default project. (Default: "false")
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Project
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        the id of the project owner.
        """
        return pulumi.get(self, "owner_id")

    @owner_id.setter
    def owner_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "owner_id", value)

    @_builtins.property
    @pulumi.getter(name="ownerUuid")
    def owner_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the unique universal identifier of the project owner.
        """
        return pulumi.get(self, "owner_uuid")

    @owner_uuid.setter
    def owner_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_uuid", value)

    @_builtins.property
    @pulumi.getter
    def purpose(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the purpose of the project, (Default: "Web Application")
        """
        return pulumi.get(self, "purpose")

    @purpose.setter
    def purpose(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "purpose", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a list of uniform resource names (URNs) for the resources associated with the project
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "resources", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the date and time when the project was last updated, (ISO8601)
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("digitalocean:index/project:Project")
class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 purpose: Optional[pulumi.Input[_builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean Project resource.

        Projects allow you to organize your resources into groups that fit the way you work.
        You can group resources (like Droplets, Spaces, Load Balancers, domains, and Floating IPs)
        in ways that align with the applications you host on DigitalOcean.

        The following resource types can be associated with a project:

        * App Platform Apps
        * Database Clusters
        * Domains
        * Droplets
        * Floating IPs
        * Kubernetes Clusters
        * Load Balancers
        * Spaces Buckets
        * Volumes

        **Note:** A provider managed project cannot be set as a default project.

        ## Example Usage

        The following example demonstrates the creation of an empty project:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        playground = digitalocean.Project("playground",
            name="playground",
            description="A project to represent development resources.",
            purpose="Web Application",
            environment="Development")
        ```

        The following example demonstrates the creation of a project with a Droplet resource:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.Droplet("foobar",
            name="example",
            size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
            image="ubuntu-22-04-x64",
            region=digitalocean.Region.NYC3)
        playground = digitalocean.Project("playground",
            name="playground",
            description="A project to represent development resources.",
            purpose="Web Application",
            environment="Development",
            resources=[foobar.droplet_urn])
        ```

        ## Import

        Projects can be imported using the `id` returned from DigitalOcean, e.g.

        ```sh
        $ pulumi import digitalocean:index/project:Project myproject 245bcfd0-7f31-4ce6-a2bc-475a116cca97
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: the description of the project
        :param pulumi.Input[_builtins.str] environment: the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        :param pulumi.Input[_builtins.bool] is_default: a boolean indicating whether or not the project is the default project. (Default: "false")
        :param pulumi.Input[_builtins.str] name: The name of the Project
        :param pulumi.Input[_builtins.str] purpose: the purpose of the project, (Default: "Web Application")
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] resources: a list of uniform resource names (URNs) for the resources associated with the project
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean Project resource.

        Projects allow you to organize your resources into groups that fit the way you work.
        You can group resources (like Droplets, Spaces, Load Balancers, domains, and Floating IPs)
        in ways that align with the applications you host on DigitalOcean.

        The following resource types can be associated with a project:

        * App Platform Apps
        * Database Clusters
        * Domains
        * Droplets
        * Floating IPs
        * Kubernetes Clusters
        * Load Balancers
        * Spaces Buckets
        * Volumes

        **Note:** A provider managed project cannot be set as a default project.

        ## Example Usage

        The following example demonstrates the creation of an empty project:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        playground = digitalocean.Project("playground",
            name="playground",
            description="A project to represent development resources.",
            purpose="Web Application",
            environment="Development")
        ```

        The following example demonstrates the creation of a project with a Droplet resource:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        foobar = digitalocean.Droplet("foobar",
            name="example",
            size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
            image="ubuntu-22-04-x64",
            region=digitalocean.Region.NYC3)
        playground = digitalocean.Project("playground",
            name="playground",
            description="A project to represent development resources.",
            purpose="Web Application",
            environment="Development",
            resources=[foobar.droplet_urn])
        ```

        ## Import

        Projects can be imported using the `id` returned from DigitalOcean, e.g.

        ```sh
        $ pulumi import digitalocean:index/project:Project myproject 245bcfd0-7f31-4ce6-a2bc-475a116cca97
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 purpose: Optional[pulumi.Input[_builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["environment"] = environment
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["name"] = name
            __props__.__dict__["purpose"] = purpose
            __props__.__dict__["resources"] = resources
            __props__.__dict__["created_at"] = None
            __props__.__dict__["owner_id"] = None
            __props__.__dict__["owner_uuid"] = None
            __props__.__dict__["updated_at"] = None
        super(Project, __self__).__init__(
            'digitalocean:index/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            owner_id: Optional[pulumi.Input[_builtins.int]] = None,
            owner_uuid: Optional[pulumi.Input[_builtins.str]] = None,
            purpose: Optional[pulumi.Input[_builtins.str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: the date and time when the project was created, (ISO8601)
        :param pulumi.Input[_builtins.str] description: the description of the project
        :param pulumi.Input[_builtins.str] environment: the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        :param pulumi.Input[_builtins.bool] is_default: a boolean indicating whether or not the project is the default project. (Default: "false")
        :param pulumi.Input[_builtins.str] name: The name of the Project
        :param pulumi.Input[_builtins.int] owner_id: the id of the project owner.
        :param pulumi.Input[_builtins.str] owner_uuid: the unique universal identifier of the project owner.
        :param pulumi.Input[_builtins.str] purpose: the purpose of the project, (Default: "Web Application")
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] resources: a list of uniform resource names (URNs) for the resources associated with the project
        :param pulumi.Input[_builtins.str] updated_at: the date and time when the project was last updated, (ISO8601)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["environment"] = environment
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["owner_id"] = owner_id
        __props__.__dict__["owner_uuid"] = owner_uuid
        __props__.__dict__["purpose"] = purpose
        __props__.__dict__["resources"] = resources
        __props__.__dict__["updated_at"] = updated_at
        return Project(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        the date and time when the project was created, (ISO8601)
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        the description of the project
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        the environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`)
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        a boolean indicating whether or not the project is the default project. (Default: "false")
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Project
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> pulumi.Output[_builtins.int]:
        """
        the id of the project owner.
        """
        return pulumi.get(self, "owner_id")

    @_builtins.property
    @pulumi.getter(name="ownerUuid")
    def owner_uuid(self) -> pulumi.Output[_builtins.str]:
        """
        the unique universal identifier of the project owner.
        """
        return pulumi.get(self, "owner_uuid")

    @_builtins.property
    @pulumi.getter
    def purpose(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        the purpose of the project, (Default: "Web Application")
        """
        return pulumi.get(self, "purpose")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        a list of uniform resource names (URNs) for the resources associated with the project
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        the date and time when the project was last updated, (ISO8601)
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._enums import *

__all__ = ['DnsRecordArgs', 'DnsRecord']

@pulumi.input_type
class DnsRecordArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[_builtins.str],
                 type: pulumi.Input[Union[_builtins.str, 'RecordType']],
                 value: pulumi.Input[_builtins.str],
                 flags: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a DnsRecord resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add the record to.
        :param pulumi.Input[Union[_builtins.str, 'RecordType']] type: The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        :param pulumi.Input[_builtins.str] value: The value of the record.
        :param pulumi.Input[_builtins.int] flags: The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        :param pulumi.Input[_builtins.str] name: The hostname of the record. Use `@` for records on domain's name itself.
        :param pulumi.Input[_builtins.int] port: The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        :param pulumi.Input[_builtins.int] priority: The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        :param pulumi.Input[_builtins.str] tag: The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        :param pulumi.Input[_builtins.int] ttl: The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        :param pulumi.Input[_builtins.int] weight: The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)
        if flags is not None:
            pulumi.set(__self__, "flags", flags)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Input[_builtins.str]:
        """
        The domain to add the record to.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[Union[_builtins.str, 'RecordType']]:
        """
        The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[Union[_builtins.str, 'RecordType']]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        The value of the record.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def flags(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        """
        return pulumi.get(self, "flags")

    @flags.setter
    def flags(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "flags", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname of the record. Use `@` for records on domain's name itself.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ttl", value)

    @_builtins.property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _DnsRecordState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 flags: Optional[pulumi.Input[_builtins.int]] = None,
                 fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering DnsRecord resources.
        :param pulumi.Input[_builtins.str] domain: The domain to add the record to.
        :param pulumi.Input[_builtins.int] flags: The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        :param pulumi.Input[_builtins.str] fqdn: The FQDN of the record
        :param pulumi.Input[_builtins.str] name: The hostname of the record. Use `@` for records on domain's name itself.
        :param pulumi.Input[_builtins.int] port: The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        :param pulumi.Input[_builtins.int] priority: The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        :param pulumi.Input[_builtins.str] tag: The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        :param pulumi.Input[_builtins.int] ttl: The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        :param pulumi.Input[Union[_builtins.str, 'RecordType']] type: The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        :param pulumi.Input[_builtins.str] value: The value of the record.
        :param pulumi.Input[_builtins.int] weight: The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if flags is not None:
            pulumi.set(__self__, "flags", flags)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain to add the record to.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter
    def flags(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        """
        return pulumi.get(self, "flags")

    @flags.setter
    def flags(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "flags", value)

    @_builtins.property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The FQDN of the record
        """
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fqdn", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname of the record. Use `@` for records on domain's name itself.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ttl", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]]:
        """
        The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the record.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.type_token("digitalocean:index/dnsRecord:DnsRecord")
class DnsRecord(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 flags: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean DNS record resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        default = digitalocean.Domain("default", name="example.com")
        # Add an A record to the domain for www.example.com.
        www = digitalocean.DnsRecord("www",
            domain=default.id,
            type=digitalocean.RecordType.A,
            name="www",
            value="192.168.0.11")
        # Add a MX record for the example.com domain itself.
        mx = digitalocean.DnsRecord("mx",
            domain=default.id,
            type=digitalocean.RecordType.MX,
            name="@",
            priority=10,
            value="mail.example.com.")
        pulumi.export("wwwFqdn", www.fqdn)
        pulumi.export("mxFqdn", mx.fqdn)
        ```

        ## Import

        Records can be imported using the domain name and record `id` when joined with a comma. See the following example:

        ```sh
        $ pulumi import digitalocean:index/dnsRecord:DnsRecord example_record example.com,12345678
        ```

        ~>  You find the `id` of the records [using the DigitalOcean API](https://docs.digitalocean.com/reference/api/digitalocean/#tag/Domain-Records/operation/domains_list_records) or CLI. Run the follow command to list the IDs for all DNS records on a domain: `doctl compute domain records list <domain.name>`

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add the record to.
        :param pulumi.Input[_builtins.int] flags: The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        :param pulumi.Input[_builtins.str] name: The hostname of the record. Use `@` for records on domain's name itself.
        :param pulumi.Input[_builtins.int] port: The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        :param pulumi.Input[_builtins.int] priority: The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        :param pulumi.Input[_builtins.str] tag: The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        :param pulumi.Input[_builtins.int] ttl: The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        :param pulumi.Input[Union[_builtins.str, 'RecordType']] type: The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        :param pulumi.Input[_builtins.str] value: The value of the record.
        :param pulumi.Input[_builtins.int] weight: The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DnsRecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean DNS record resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        default = digitalocean.Domain("default", name="example.com")
        # Add an A record to the domain for www.example.com.
        www = digitalocean.DnsRecord("www",
            domain=default.id,
            type=digitalocean.RecordType.A,
            name="www",
            value="192.168.0.11")
        # Add a MX record for the example.com domain itself.
        mx = digitalocean.DnsRecord("mx",
            domain=default.id,
            type=digitalocean.RecordType.MX,
            name="@",
            priority=10,
            value="mail.example.com.")
        pulumi.export("wwwFqdn", www.fqdn)
        pulumi.export("mxFqdn", mx.fqdn)
        ```

        ## Import

        Records can be imported using the domain name and record `id` when joined with a comma. See the following example:

        ```sh
        $ pulumi import digitalocean:index/dnsRecord:DnsRecord example_record example.com,12345678
        ```

        ~>  You find the `id` of the records [using the DigitalOcean API](https://docs.digitalocean.com/reference/api/digitalocean/#tag/Domain-Records/operation/domains_list_records) or CLI. Run the follow command to list the IDs for all DNS records on a domain: `doctl compute domain records list <domain.name>`

        :param str resource_name: The name of the resource.
        :param DnsRecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnsRecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 flags: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnsRecordArgs.__new__(DnsRecordArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["flags"] = flags
            __props__.__dict__["name"] = name
            __props__.__dict__["port"] = port
            __props__.__dict__["priority"] = priority
            __props__.__dict__["tag"] = tag
            __props__.__dict__["ttl"] = ttl
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
            __props__.__dict__["weight"] = weight
            __props__.__dict__["fqdn"] = None
        super(DnsRecord, __self__).__init__(
            'digitalocean:index/dnsRecord:DnsRecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[_builtins.str]] = None,
            flags: Optional[pulumi.Input[_builtins.int]] = None,
            fqdn: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            tag: Optional[pulumi.Input[_builtins.str]] = None,
            ttl: Optional[pulumi.Input[_builtins.int]] = None,
            type: Optional[pulumi.Input[Union[_builtins.str, 'RecordType']]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            weight: Optional[pulumi.Input[_builtins.int]] = None) -> 'DnsRecord':
        """
        Get an existing DnsRecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add the record to.
        :param pulumi.Input[_builtins.int] flags: The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        :param pulumi.Input[_builtins.str] fqdn: The FQDN of the record
        :param pulumi.Input[_builtins.str] name: The hostname of the record. Use `@` for records on domain's name itself.
        :param pulumi.Input[_builtins.int] port: The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        :param pulumi.Input[_builtins.int] priority: The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        :param pulumi.Input[_builtins.str] tag: The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        :param pulumi.Input[_builtins.int] ttl: The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        :param pulumi.Input[Union[_builtins.str, 'RecordType']] type: The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        :param pulumi.Input[_builtins.str] value: The value of the record.
        :param pulumi.Input[_builtins.int] weight: The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnsRecordState.__new__(_DnsRecordState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["flags"] = flags
        __props__.__dict__["fqdn"] = fqdn
        __props__.__dict__["name"] = name
        __props__.__dict__["port"] = port
        __props__.__dict__["priority"] = priority
        __props__.__dict__["tag"] = tag
        __props__.__dict__["ttl"] = ttl
        __props__.__dict__["type"] = type
        __props__.__dict__["value"] = value
        __props__.__dict__["weight"] = weight
        return DnsRecord(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Output[_builtins.str]:
        """
        The domain to add the record to.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def flags(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The flags of the record. Only valid when type is `CAA`. Must be between 0 and 255.
        """
        return pulumi.get(self, "flags")

    @_builtins.property
    @pulumi.getter
    def fqdn(self) -> pulumi.Output[_builtins.str]:
        """
        The FQDN of the record
        """
        return pulumi.get(self, "fqdn")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The hostname of the record. Use `@` for records on domain's name itself.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The port of the record. Only valid when type is `SRV`.  Must be between 1 and 65535.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The priority of the record. Only valid when type is `MX` or `SRV`. Must be between 0 and 65535.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def tag(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The tag of the record. Only valid when type is `CAA`. Must be one of `issue`, `issuewild`, or `iodef`.
        """
        return pulumi.get(self, "tag")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[_builtins.int]:
        """
        The time to live for the record, in seconds. Must be at least 0. Defaults to 1800.
        """
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of record. Must be one of `A`, `AAAA`, `CAA`, `CNAME`, `MX`, `NS`, `TXT`, or `SRV`.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.str]:
        """
        The value of the record.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter
    def weight(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The weight of the record. Only valid when type is `SRV`.  Must be between 0 and 65535.
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKubernetesClusterResult',
    'AwaitableGetKubernetesClusterResult',
    'get_kubernetes_cluster',
    'get_kubernetes_cluster_output',
]

@pulumi.output_type
class GetKubernetesClusterResult:
    """
    A collection of values returned by getKubernetesCluster.
    """
    def __init__(__self__, auto_upgrade=None, cluster_autoscaler_configurations=None, cluster_subnet=None, control_plane_firewalls=None, created_at=None, endpoint=None, ha=None, id=None, ipv4_address=None, kube_configs=None, kubeconfig_expire_seconds=None, maintenance_policies=None, name=None, node_pools=None, region=None, routing_agent=None, service_subnet=None, status=None, surge_upgrade=None, tags=None, updated_at=None, urn=None, version=None, vpc_uuid=None):
        if auto_upgrade and not isinstance(auto_upgrade, bool):
            raise TypeError("Expected argument 'auto_upgrade' to be a bool")
        pulumi.set(__self__, "auto_upgrade", auto_upgrade)
        if cluster_autoscaler_configurations and not isinstance(cluster_autoscaler_configurations, list):
            raise TypeError("Expected argument 'cluster_autoscaler_configurations' to be a list")
        pulumi.set(__self__, "cluster_autoscaler_configurations", cluster_autoscaler_configurations)
        if cluster_subnet and not isinstance(cluster_subnet, str):
            raise TypeError("Expected argument 'cluster_subnet' to be a str")
        pulumi.set(__self__, "cluster_subnet", cluster_subnet)
        if control_plane_firewalls and not isinstance(control_plane_firewalls, list):
            raise TypeError("Expected argument 'control_plane_firewalls' to be a list")
        pulumi.set(__self__, "control_plane_firewalls", control_plane_firewalls)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if ha and not isinstance(ha, bool):
            raise TypeError("Expected argument 'ha' to be a bool")
        pulumi.set(__self__, "ha", ha)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv4_address and not isinstance(ipv4_address, str):
            raise TypeError("Expected argument 'ipv4_address' to be a str")
        pulumi.set(__self__, "ipv4_address", ipv4_address)
        if kube_configs and not isinstance(kube_configs, list):
            raise TypeError("Expected argument 'kube_configs' to be a list")
        pulumi.set(__self__, "kube_configs", kube_configs)
        if kubeconfig_expire_seconds and not isinstance(kubeconfig_expire_seconds, int):
            raise TypeError("Expected argument 'kubeconfig_expire_seconds' to be a int")
        pulumi.set(__self__, "kubeconfig_expire_seconds", kubeconfig_expire_seconds)
        if maintenance_policies and not isinstance(maintenance_policies, list):
            raise TypeError("Expected argument 'maintenance_policies' to be a list")
        pulumi.set(__self__, "maintenance_policies", maintenance_policies)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_pools and not isinstance(node_pools, list):
            raise TypeError("Expected argument 'node_pools' to be a list")
        pulumi.set(__self__, "node_pools", node_pools)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if routing_agent and not isinstance(routing_agent, dict):
            raise TypeError("Expected argument 'routing_agent' to be a dict")
        pulumi.set(__self__, "routing_agent", routing_agent)
        if service_subnet and not isinstance(service_subnet, str):
            raise TypeError("Expected argument 'service_subnet' to be a str")
        pulumi.set(__self__, "service_subnet", service_subnet)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if surge_upgrade and not isinstance(surge_upgrade, bool):
            raise TypeError("Expected argument 'surge_upgrade' to be a bool")
        pulumi.set(__self__, "surge_upgrade", surge_upgrade)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if vpc_uuid and not isinstance(vpc_uuid, str):
            raise TypeError("Expected argument 'vpc_uuid' to be a str")
        pulumi.set(__self__, "vpc_uuid", vpc_uuid)

    @_builtins.property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> _builtins.bool:
        """
        A boolean value indicating whether the cluster will be automatically upgraded to new patch releases during its maintenance window.
        """
        return pulumi.get(self, "auto_upgrade")

    @_builtins.property
    @pulumi.getter(name="clusterAutoscalerConfigurations")
    def cluster_autoscaler_configurations(self) -> Optional[Sequence['outputs.GetKubernetesClusterClusterAutoscalerConfigurationResult']]:
        return pulumi.get(self, "cluster_autoscaler_configurations")

    @_builtins.property
    @pulumi.getter(name="clusterSubnet")
    def cluster_subnet(self) -> _builtins.str:
        """
        The range of IP addresses in the overlay network of the Kubernetes cluster.
        """
        return pulumi.get(self, "cluster_subnet")

    @_builtins.property
    @pulumi.getter(name="controlPlaneFirewalls")
    def control_plane_firewalls(self) -> Sequence['outputs.GetKubernetesClusterControlPlaneFirewallResult']:
        return pulumi.get(self, "control_plane_firewalls")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time when the node was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        The base URL of the API server on the Kubernetes master node.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def ha(self) -> _builtins.bool:
        return pulumi.get(self, "ha")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipv4Address")
    def ipv4_address(self) -> _builtins.str:
        """
        The public IPv4 address of the Kubernetes master node.
        """
        return pulumi.get(self, "ipv4_address")

    @_builtins.property
    @pulumi.getter(name="kubeConfigs")
    def kube_configs(self) -> Sequence['outputs.GetKubernetesClusterKubeConfigResult']:
        """
        A representation of the Kubernetes cluster's kubeconfig with the following attributes:
        """
        return pulumi.get(self, "kube_configs")

    @_builtins.property
    @pulumi.getter(name="kubeconfigExpireSeconds")
    def kubeconfig_expire_seconds(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "kubeconfig_expire_seconds")

    @_builtins.property
    @pulumi.getter(name="maintenancePolicies")
    def maintenance_policies(self) -> Sequence['outputs.GetKubernetesClusterMaintenancePolicyResult']:
        """
        The maintenance policy of the Kubernetes cluster. Digital Ocean has a default maintenancen window.
        """
        return pulumi.get(self, "maintenance_policies")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The auto-generated name for the node.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodePools")
    def node_pools(self) -> Sequence['outputs.GetKubernetesClusterNodePoolResult']:
        """
        A list of node pools associated with the cluster. Each node pool exports the following attributes:
        """
        return pulumi.get(self, "node_pools")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The slug identifier for the region where the Kubernetes cluster is located.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routingAgent")
    def routing_agent(self) -> 'outputs.GetKubernetesClusterRoutingAgentResult':
        return pulumi.get(self, "routing_agent")

    @_builtins.property
    @pulumi.getter(name="serviceSubnet")
    def service_subnet(self) -> _builtins.str:
        """
        The range of assignable IP addresses for services running in the Kubernetes cluster.
        """
        return pulumi.get(self, "service_subnet")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        A string indicating the current status of the individual node.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="surgeUpgrade")
    def surge_upgrade(self) -> _builtins.bool:
        return pulumi.get(self, "surge_upgrade")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of tag names applied to the node pool.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time when the node was last updated.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name (URN) for the Kubernetes cluster.
        """
        return pulumi.get(self, "urn")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        The slug identifier for the version of Kubernetes used for the cluster.
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter(name="vpcUuid")
    def vpc_uuid(self) -> _builtins.str:
        """
        The ID of the VPC where the Kubernetes cluster is located.
        """
        return pulumi.get(self, "vpc_uuid")


class AwaitableGetKubernetesClusterResult(GetKubernetesClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubernetesClusterResult(
            auto_upgrade=self.auto_upgrade,
            cluster_autoscaler_configurations=self.cluster_autoscaler_configurations,
            cluster_subnet=self.cluster_subnet,
            control_plane_firewalls=self.control_plane_firewalls,
            created_at=self.created_at,
            endpoint=self.endpoint,
            ha=self.ha,
            id=self.id,
            ipv4_address=self.ipv4_address,
            kube_configs=self.kube_configs,
            kubeconfig_expire_seconds=self.kubeconfig_expire_seconds,
            maintenance_policies=self.maintenance_policies,
            name=self.name,
            node_pools=self.node_pools,
            region=self.region,
            routing_agent=self.routing_agent,
            service_subnet=self.service_subnet,
            status=self.status,
            surge_upgrade=self.surge_upgrade,
            tags=self.tags,
            updated_at=self.updated_at,
            urn=self.urn,
            version=self.version,
            vpc_uuid=self.vpc_uuid)


def get_kubernetes_cluster(cluster_autoscaler_configurations: Optional[Sequence[Union['GetKubernetesClusterClusterAutoscalerConfigurationArgs', 'GetKubernetesClusterClusterAutoscalerConfigurationArgsDict']]] = None,
                           kubeconfig_expire_seconds: Optional[_builtins.int] = None,
                           name: Optional[_builtins.str] = None,
                           routing_agent: Optional[Union['GetKubernetesClusterRoutingAgentArgs', 'GetKubernetesClusterRoutingAgentArgsDict']] = None,
                           tags: Optional[Sequence[_builtins.str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKubernetesClusterResult:
    """
    Retrieves information about a DigitalOcean Kubernetes cluster for use in other resources. This data source provides all of the cluster's properties as configured on your DigitalOcean account. This is useful if the cluster in question is not managed by the provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_kubernetes_cluster(name="prod-cluster-01")
    ```


    :param _builtins.str name: The name of Kubernetes cluster.
    :param Sequence[_builtins.str] tags: A list of tag names applied to the node pool.
    """
    __args__ = dict()
    __args__['clusterAutoscalerConfigurations'] = cluster_autoscaler_configurations
    __args__['kubeconfigExpireSeconds'] = kubeconfig_expire_seconds
    __args__['name'] = name
    __args__['routingAgent'] = routing_agent
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getKubernetesCluster:getKubernetesCluster', __args__, opts=opts, typ=GetKubernetesClusterResult).value

    return AwaitableGetKubernetesClusterResult(
        auto_upgrade=pulumi.get(__ret__, 'auto_upgrade'),
        cluster_autoscaler_configurations=pulumi.get(__ret__, 'cluster_autoscaler_configurations'),
        cluster_subnet=pulumi.get(__ret__, 'cluster_subnet'),
        control_plane_firewalls=pulumi.get(__ret__, 'control_plane_firewalls'),
        created_at=pulumi.get(__ret__, 'created_at'),
        endpoint=pulumi.get(__ret__, 'endpoint'),
        ha=pulumi.get(__ret__, 'ha'),
        id=pulumi.get(__ret__, 'id'),
        ipv4_address=pulumi.get(__ret__, 'ipv4_address'),
        kube_configs=pulumi.get(__ret__, 'kube_configs'),
        kubeconfig_expire_seconds=pulumi.get(__ret__, 'kubeconfig_expire_seconds'),
        maintenance_policies=pulumi.get(__ret__, 'maintenance_policies'),
        name=pulumi.get(__ret__, 'name'),
        node_pools=pulumi.get(__ret__, 'node_pools'),
        region=pulumi.get(__ret__, 'region'),
        routing_agent=pulumi.get(__ret__, 'routing_agent'),
        service_subnet=pulumi.get(__ret__, 'service_subnet'),
        status=pulumi.get(__ret__, 'status'),
        surge_upgrade=pulumi.get(__ret__, 'surge_upgrade'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        urn=pulumi.get(__ret__, 'urn'),
        version=pulumi.get(__ret__, 'version'),
        vpc_uuid=pulumi.get(__ret__, 'vpc_uuid'))
def get_kubernetes_cluster_output(cluster_autoscaler_configurations: Optional[pulumi.Input[Optional[Sequence[Union['GetKubernetesClusterClusterAutoscalerConfigurationArgs', 'GetKubernetesClusterClusterAutoscalerConfigurationArgsDict']]]]] = None,
                                  kubeconfig_expire_seconds: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                  name: Optional[pulumi.Input[_builtins.str]] = None,
                                  routing_agent: Optional[pulumi.Input[Optional[Union['GetKubernetesClusterRoutingAgentArgs', 'GetKubernetesClusterRoutingAgentArgsDict']]]] = None,
                                  tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKubernetesClusterResult]:
    """
    Retrieves information about a DigitalOcean Kubernetes cluster for use in other resources. This data source provides all of the cluster's properties as configured on your DigitalOcean account. This is useful if the cluster in question is not managed by the provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_kubernetes_cluster(name="prod-cluster-01")
    ```


    :param _builtins.str name: The name of Kubernetes cluster.
    :param Sequence[_builtins.str] tags: A list of tag names applied to the node pool.
    """
    __args__ = dict()
    __args__['clusterAutoscalerConfigurations'] = cluster_autoscaler_configurations
    __args__['kubeconfigExpireSeconds'] = kubeconfig_expire_seconds
    __args__['name'] = name
    __args__['routingAgent'] = routing_agent
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getKubernetesCluster:getKubernetesCluster', __args__, opts=opts, typ=GetKubernetesClusterResult)
    return __ret__.apply(lambda __response__: GetKubernetesClusterResult(
        auto_upgrade=pulumi.get(__response__, 'auto_upgrade'),
        cluster_autoscaler_configurations=pulumi.get(__response__, 'cluster_autoscaler_configurations'),
        cluster_subnet=pulumi.get(__response__, 'cluster_subnet'),
        control_plane_firewalls=pulumi.get(__response__, 'control_plane_firewalls'),
        created_at=pulumi.get(__response__, 'created_at'),
        endpoint=pulumi.get(__response__, 'endpoint'),
        ha=pulumi.get(__response__, 'ha'),
        id=pulumi.get(__response__, 'id'),
        ipv4_address=pulumi.get(__response__, 'ipv4_address'),
        kube_configs=pulumi.get(__response__, 'kube_configs'),
        kubeconfig_expire_seconds=pulumi.get(__response__, 'kubeconfig_expire_seconds'),
        maintenance_policies=pulumi.get(__response__, 'maintenance_policies'),
        name=pulumi.get(__response__, 'name'),
        node_pools=pulumi.get(__response__, 'node_pools'),
        region=pulumi.get(__response__, 'region'),
        routing_agent=pulumi.get(__response__, 'routing_agent'),
        service_subnet=pulumi.get(__response__, 'service_subnet'),
        status=pulumi.get(__response__, 'status'),
        surge_upgrade=pulumi.get(__response__, 'surge_upgrade'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        urn=pulumi.get(__response__, 'urn'),
        version=pulumi.get(__response__, 'version'),
        vpc_uuid=pulumi.get(__response__, 'vpc_uuid')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GenaiAgentRouteArgs', 'GenaiAgentRoute']

@pulumi.input_type
class GenaiAgentRouteArgs:
    def __init__(__self__, *,
                 child_agent_uuid: pulumi.Input[_builtins.str],
                 parent_agent_uuid: pulumi.Input[_builtins.str],
                 if_case: Optional[pulumi.Input[_builtins.str]] = None,
                 rollback: Optional[pulumi.Input[_builtins.bool]] = None,
                 route_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GenaiAgentRoute resource.
        :param pulumi.Input[_builtins.str] child_agent_uuid: The UUID of the child agent.
        :param pulumi.Input[_builtins.str] parent_agent_uuid: The UUID of the parent agent.
        :param pulumi.Input[_builtins.str] if_case: if-case condition for the route.
        :param pulumi.Input[_builtins.str] route_name: A name for the route.
        """
        pulumi.set(__self__, "child_agent_uuid", child_agent_uuid)
        pulumi.set(__self__, "parent_agent_uuid", parent_agent_uuid)
        if if_case is not None:
            pulumi.set(__self__, "if_case", if_case)
        if rollback is not None:
            pulumi.set(__self__, "rollback", rollback)
        if route_name is not None:
            pulumi.set(__self__, "route_name", route_name)

    @_builtins.property
    @pulumi.getter(name="childAgentUuid")
    def child_agent_uuid(self) -> pulumi.Input[_builtins.str]:
        """
        The UUID of the child agent.
        """
        return pulumi.get(self, "child_agent_uuid")

    @child_agent_uuid.setter
    def child_agent_uuid(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "child_agent_uuid", value)

    @_builtins.property
    @pulumi.getter(name="parentAgentUuid")
    def parent_agent_uuid(self) -> pulumi.Input[_builtins.str]:
        """
        The UUID of the parent agent.
        """
        return pulumi.get(self, "parent_agent_uuid")

    @parent_agent_uuid.setter
    def parent_agent_uuid(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent_agent_uuid", value)

    @_builtins.property
    @pulumi.getter(name="ifCase")
    def if_case(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        if-case condition for the route.
        """
        return pulumi.get(self, "if_case")

    @if_case.setter
    def if_case(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "if_case", value)

    @_builtins.property
    @pulumi.getter
    def rollback(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "rollback")

    @rollback.setter
    def rollback(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "rollback", value)

    @_builtins.property
    @pulumi.getter(name="routeName")
    def route_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the route.
        """
        return pulumi.get(self, "route_name")

    @route_name.setter
    def route_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_name", value)


@pulumi.input_type
class _GenaiAgentRouteState:
    def __init__(__self__, *,
                 child_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 if_case: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 rollback: Optional[pulumi.Input[_builtins.bool]] = None,
                 route_name: Optional[pulumi.Input[_builtins.str]] = None,
                 uuid: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GenaiAgentRoute resources.
        :param pulumi.Input[_builtins.str] child_agent_uuid: The UUID of the child agent.
        :param pulumi.Input[_builtins.str] if_case: if-case condition for the route.
        :param pulumi.Input[_builtins.str] parent_agent_uuid: The UUID of the parent agent.
        :param pulumi.Input[_builtins.str] route_name: A name for the route.
        :param pulumi.Input[_builtins.str] uuid: The UUID of the linkage
        """
        if child_agent_uuid is not None:
            pulumi.set(__self__, "child_agent_uuid", child_agent_uuid)
        if if_case is not None:
            pulumi.set(__self__, "if_case", if_case)
        if parent_agent_uuid is not None:
            pulumi.set(__self__, "parent_agent_uuid", parent_agent_uuid)
        if rollback is not None:
            pulumi.set(__self__, "rollback", rollback)
        if route_name is not None:
            pulumi.set(__self__, "route_name", route_name)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)

    @_builtins.property
    @pulumi.getter(name="childAgentUuid")
    def child_agent_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the child agent.
        """
        return pulumi.get(self, "child_agent_uuid")

    @child_agent_uuid.setter
    def child_agent_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "child_agent_uuid", value)

    @_builtins.property
    @pulumi.getter(name="ifCase")
    def if_case(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        if-case condition for the route.
        """
        return pulumi.get(self, "if_case")

    @if_case.setter
    def if_case(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "if_case", value)

    @_builtins.property
    @pulumi.getter(name="parentAgentUuid")
    def parent_agent_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the parent agent.
        """
        return pulumi.get(self, "parent_agent_uuid")

    @parent_agent_uuid.setter
    def parent_agent_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_agent_uuid", value)

    @_builtins.property
    @pulumi.getter
    def rollback(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "rollback")

    @rollback.setter
    def rollback(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "rollback", value)

    @_builtins.property
    @pulumi.getter(name="routeName")
    def route_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the route.
        """
        return pulumi.get(self, "route_name")

    @route_name.setter
    def route_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_name", value)

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the linkage
        """
        return pulumi.get(self, "uuid")

    @uuid.setter
    def uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uuid", value)


@pulumi.type_token("digitalocean:index/genaiAgentRoute:GenaiAgentRoute")
class GenaiAgentRoute(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 child_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 if_case: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 rollback: Optional[pulumi.Input[_builtins.bool]] = None,
                 route_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a GenaiAgentRoute resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] child_agent_uuid: The UUID of the child agent.
        :param pulumi.Input[_builtins.str] if_case: if-case condition for the route.
        :param pulumi.Input[_builtins.str] parent_agent_uuid: The UUID of the parent agent.
        :param pulumi.Input[_builtins.str] route_name: A name for the route.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GenaiAgentRouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a GenaiAgentRoute resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param GenaiAgentRouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GenaiAgentRouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 child_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 if_case: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 rollback: Optional[pulumi.Input[_builtins.bool]] = None,
                 route_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GenaiAgentRouteArgs.__new__(GenaiAgentRouteArgs)

            if child_agent_uuid is None and not opts.urn:
                raise TypeError("Missing required property 'child_agent_uuid'")
            __props__.__dict__["child_agent_uuid"] = child_agent_uuid
            __props__.__dict__["if_case"] = if_case
            if parent_agent_uuid is None and not opts.urn:
                raise TypeError("Missing required property 'parent_agent_uuid'")
            __props__.__dict__["parent_agent_uuid"] = parent_agent_uuid
            __props__.__dict__["rollback"] = rollback
            __props__.__dict__["route_name"] = route_name
            __props__.__dict__["uuid"] = None
        super(GenaiAgentRoute, __self__).__init__(
            'digitalocean:index/genaiAgentRoute:GenaiAgentRoute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            child_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
            if_case: Optional[pulumi.Input[_builtins.str]] = None,
            parent_agent_uuid: Optional[pulumi.Input[_builtins.str]] = None,
            rollback: Optional[pulumi.Input[_builtins.bool]] = None,
            route_name: Optional[pulumi.Input[_builtins.str]] = None,
            uuid: Optional[pulumi.Input[_builtins.str]] = None) -> 'GenaiAgentRoute':
        """
        Get an existing GenaiAgentRoute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] child_agent_uuid: The UUID of the child agent.
        :param pulumi.Input[_builtins.str] if_case: if-case condition for the route.
        :param pulumi.Input[_builtins.str] parent_agent_uuid: The UUID of the parent agent.
        :param pulumi.Input[_builtins.str] route_name: A name for the route.
        :param pulumi.Input[_builtins.str] uuid: The UUID of the linkage
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GenaiAgentRouteState.__new__(_GenaiAgentRouteState)

        __props__.__dict__["child_agent_uuid"] = child_agent_uuid
        __props__.__dict__["if_case"] = if_case
        __props__.__dict__["parent_agent_uuid"] = parent_agent_uuid
        __props__.__dict__["rollback"] = rollback
        __props__.__dict__["route_name"] = route_name
        __props__.__dict__["uuid"] = uuid
        return GenaiAgentRoute(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="childAgentUuid")
    def child_agent_uuid(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the child agent.
        """
        return pulumi.get(self, "child_agent_uuid")

    @_builtins.property
    @pulumi.getter(name="ifCase")
    def if_case(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        if-case condition for the route.
        """
        return pulumi.get(self, "if_case")

    @_builtins.property
    @pulumi.getter(name="parentAgentUuid")
    def parent_agent_uuid(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the parent agent.
        """
        return pulumi.get(self, "parent_agent_uuid")

    @_builtins.property
    @pulumi.getter
    def rollback(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "rollback")

    @_builtins.property
    @pulumi.getter(name="routeName")
    def route_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A name for the route.
        """
        return pulumi.get(self, "route_name")

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the linkage
        """
        return pulumi.get(self, "uuid")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRegionResult',
    'AwaitableGetRegionResult',
    'get_region',
    'get_region_output',
]

@pulumi.output_type
class GetRegionResult:
    """
    A collection of values returned by getRegion.
    """
    def __init__(__self__, available=None, features=None, id=None, name=None, sizes=None, slug=None):
        if available and not isinstance(available, bool):
            raise TypeError("Expected argument 'available' to be a bool")
        pulumi.set(__self__, "available", available)
        if features and not isinstance(features, list):
            raise TypeError("Expected argument 'features' to be a list")
        pulumi.set(__self__, "features", features)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sizes and not isinstance(sizes, list):
            raise TypeError("Expected argument 'sizes' to be a list")
        pulumi.set(__self__, "sizes", sizes)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)

    @_builtins.property
    @pulumi.getter
    def available(self) -> _builtins.bool:
        """
        A boolean value that represents whether new Droplets can be created in this region.
        """
        return pulumi.get(self, "available")

    @_builtins.property
    @pulumi.getter
    def features(self) -> Sequence[_builtins.str]:
        """
        A set of features available in this region.
        """
        return pulumi.get(self, "features")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The display name of the region.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def sizes(self) -> Sequence[_builtins.str]:
        """
        A set of identifying slugs for the Droplet sizes available in this region.
        """
        return pulumi.get(self, "sizes")

    @_builtins.property
    @pulumi.getter
    def slug(self) -> _builtins.str:
        """
        A human-readable string that is used as a unique identifier for each region.
        """
        return pulumi.get(self, "slug")


class AwaitableGetRegionResult(GetRegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionResult(
            available=self.available,
            features=self.features,
            id=self.id,
            name=self.name,
            sizes=self.sizes,
            slug=self.slug)


def get_region(slug: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionResult:
    """
    Get information on a single DigitalOcean region. This is useful to find out
    what Droplet sizes and features are supported within a region.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    sfo2 = digitalocean.get_region(slug="sfo2")
    pulumi.export("regionName", sfo2.name)
    ```


    :param _builtins.str slug: A human-readable string that is used as a unique identifier for each region.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getRegion:getRegion', __args__, opts=opts, typ=GetRegionResult).value

    return AwaitableGetRegionResult(
        available=pulumi.get(__ret__, 'available'),
        features=pulumi.get(__ret__, 'features'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        sizes=pulumi.get(__ret__, 'sizes'),
        slug=pulumi.get(__ret__, 'slug'))
def get_region_output(slug: Optional[pulumi.Input[_builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegionResult]:
    """
    Get information on a single DigitalOcean region. This is useful to find out
    what Droplet sizes and features are supported within a region.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    sfo2 = digitalocean.get_region(slug="sfo2")
    pulumi.export("regionName", sfo2.name)
    ```


    :param _builtins.str slug: A human-readable string that is used as a unique identifier for each region.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getRegion:getRegion', __args__, opts=opts, typ=GetRegionResult)
    return __ret__.apply(lambda __response__: GetRegionResult(
        available=pulumi.get(__response__, 'available'),
        features=pulumi.get(__response__, 'features'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        sizes=pulumi.get(__response__, 'sizes'),
        slug=pulumi.get(__response__, 'slug')))
